#ifndef DEVTOOLS_H
#define DEVTOOLS_H

#include "dyalog.h"

class QWidget;

/** Display developer tools. */
class DevTools: public Dyalog
{
    Q_OBJECT

public:
    explicit DevTools(QWidget *parent = 0);

public slots:
    void onClear();
    void onLevelButtonClicked(int level);
};

#endif // DEVTOOLS_H
